@@ -1,6 +1,9 @@
-use adler::Adler32;
 use ggrs::{Frame, GGRSRequest, GameStateCell, NULL_FRAME};
 use ggrs::{GGRSError, GGRSEvent, GameInput, GameState, PlayerHandle, PlayerType, SessionState};
+use sdl2::event::Event;
+use sdl2::keyboard::Keycode;
+use sdl2::pixels::Color;
+use sdl2::rect::Rect;
 use sdl2::render::Canvas;
 use sdl2::video::Window;
 use sdl2::EventPump;
@@ -10,11 +13,6 @@ use std::hash::Hash;
 use std::net::SocketAddr;
 use std::time::{Duration, Instant};
 
-use sdl2::event::Event;
-use sdl2::keyboard::Keycode;
-use sdl2::pixels::Color;
-use sdl2::rect::Rect;
-
 const FPS: i32 = 60;
 const NUM_PLAYERS: usize = 2;
 const INPUT_SIZE: usize = std::mem::size_of::<u8>();
@@ -31,9 +29,8 @@ const INPUT_RIGHT: u8 = 1 << 3;
 
 const PLAYER_SPEED: i32 = 240;
 
-// BoxGame holds the gamestate and acts as an interface for GGRS
 struct BoxGame {
-    pub game_state: BoxGameState, // the game state
+    pub game_state: BoxGameState,
 }
 
 impl BoxGame {
@@ -56,15 +53,8 @@ impl BoxGame {
     fn save_game_state(&mut self, cell: GameStateCell, frame: Frame) {
         assert_eq!(self.game_state.frame, frame);
         let buffer = bincode::serialize(&self.game_state).unwrap();
-        let mut adler = Adler32::new();
-        self.game_state.hash(&mut adler);
-        let checksum = adler.checksum();
 
-        cell.save(GameState {
-            frame: self.game_state.frame,
-            buffer: Some(buffer),
-            checksum: Some(checksum),
-        });
+        cell.save(GameState::new(frame, Some(buffer), None));
     }
 
     fn load_game_state(&mut self, cell: GameStateCell) {
@@ -269,7 +259,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         if Instant::now() < next {
             continue;
         }
-        next = Instant::now() + Duration::from_micros(16667); // 60 fps
+        next = Instant::now() + Duration::from_micros(1000000 / FPS as u64); // 60 fps
 
         // do stuff only when the session is ready
         if sess.current_state() == SessionState::Running {
