@@ -93,12 +93,10 @@ impl SavedStates {
         self.states[self.head].clone()
     }
 
-    #[allow(dead_code)]
-    fn latest(&self) -> Option<GameStateCell> {
+    fn by_frame(&self, frame: Frame) -> Option<GameStateCell> {
         self.states
             .iter()
-            .filter(|saved| saved.0.lock().frame != NULL_FRAME)
-            .max_by_key(|saved| saved.0.lock().frame)
+            .find(|saved| saved.0.lock().frame == frame)
             .cloned()
     }
 }
@@ -261,19 +259,27 @@ impl SyncLayer {
         }
     }
 
+    /// Finds the earliest incorrect frame detected by the individual input queues
     pub(crate) fn check_simulation_consistency(&self) -> Option<Frame> {
         let mut first_incorrect: Frame = NULL_FRAME;
         for handle in 0..self.num_players as usize {
-            first_incorrect = std::cmp::max(
-                first_incorrect,
-                self.input_queues[handle].first_incorrect_frame(),
-            );
+            let incorrect = self.input_queues[handle].first_incorrect_frame();
+            if incorrect != NULL_FRAME
+                && (first_incorrect == NULL_FRAME || incorrect < first_incorrect)
+            {
+                first_incorrect = incorrect;
+            }
         }
         match first_incorrect {
             NULL_FRAME => None,
             _ => Some(first_incorrect),
         }
     }
+
+    /// Returns the latest saved gamestate
+    pub(crate) fn saved_state_by_frame(&self, frame: Frame) -> Option<GameStateCell> {
+        self.saved_states.by_frame(frame)
+    }
 }
 
 // #########
